Package 'slurmwiz'

Title: Convert Raw Mass Spectrometry Files
Description: Wrapper for converting raw mass spectrometry data files using the pwiz docker container through apptainer on a high performance computer (HPC) cluster running SLRUM workload manager.
Authors: Tom Wilson [aut, cre]
Maintainer: Tom Wilson <[email protected]>
License: GPL (>= 3)
Version: 0.1.4
Built: 2026-06-01 23:04:53 UTC
Source: https://github.com/wilsontom/slurmwiz

Help Index


Detect File Type

Description

Detect the main file type in a directory of raw files

Usage

detect_file_type(input)

Arguments

input

the absolute file path of the directory of raw files for conversion

Value

a character string of the file type for conversion


Convert Raw Files using msconvert and SLURM

Description

Convert raw mass spectrometry files using a combination of singularity, t

Usage

slurm_convert(input, output, format_out, conversion_args)

Arguments

input

the absolute file path of the directory of raw files for conversion

output

the absolute file path where converted data files will be saved to

format_out

a character string of msconvert format for conversioin.

conversion_args

a character string of msconvert arguments without the --filter prefix (ie, ⁠peakPicking true 1-⁠)

Examples

## Not run: 
slurm_convert(input = 'hpc/storage/my_raw_data', output = 'hpc/home/my_converted_data', format_out = 'mzML', conversion_args = c('peakPicking true 1-'))

## End(Not run)